Release Notes
=============

.. role:: small

Version 1.0
-----------

1.0.3 :small:`2020-12-08`
~~~~~~~~~~~~~~~~~~~~~~~~~
- Add :class:`omnipath.interactions.PostTranslational`
- Add possibility to download all :class:`omnipath.requests.Annotations`

1.0.2 :small:`2020-11-29`
~~~~~~~~~~~~~~~~~~~~~~~~~
- Fix small bug when converting boolean values
- Fix typos
- Add option to create interaction graphs

1.0.1 :small:`2020-11-29`
~~~~~~~~~~~~~~~~~~~~~~~~~
- Fix bug of not correctly passing datasets in interactions
- Fix the way the progress bar is getting content size
- Add comparison tests with OmnipathR

1.0.0 :small:`2020-11-23`
~~~~~~~~~~~~~~~~~~~~~~~~~
- Fix minor bugs
- Add options improvements
- Add tests

Version 0.0
-----------

0.0.0 :small:`2020-11-15`
~~~~~~~~~~~~~~~~~~~~~~~~~
- Initial release
